#[non_exhaustive]pub enum BlockHeaderDecodeErrorCategory {
MalformedInput,
ResourceExhaustion,
}Expand description
Stable high-level header decode error categories.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MalformedInput
Input is malformed for the selected header field set.
ResourceExhaustion
The active decode policy rejected the input as too large or too deep.