#[non_exhaustive]pub enum FeatureError {
Disabled,
Unsupported,
}Expand description
Feature availability failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Disabled
The feature is intentionally not enabled for this build or context.
Unsupported
The feature is not implemented by this crate version.
Implementations