ForkError

Enum ForkError 

#[non_exhaustive]
pub enum ForkError { Unsupported, Inactive, MissingActivation, ChainMismatch, DuplicateFork, NonMonotonicForkOrder, }
Fork selection or activation failure.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unsupported

The selected fork is absent from the supplied chain spec.



Inactive

The selected fork is not active for the supplied validation context.



MissingActivation

Fork activation data is incomplete.



ChainMismatch

A fork spec was supplied for a different chain.



DuplicateFork

The chain spec contains the same hardfork more than once.



NonMonotonicForkOrder

The chain spec hardfork entries are not in chronological order.

Implementations

Source

impl ForkError

pub const fn code(self) -> &'static str

Stable machine-readable error code.

pub const fn message(self) -> &'static str

Stable human-readable error message.