#[non_exhaustive]pub enum LegacyTransactionDecodeError {
Envelope(TransactionEnvelopeError),
TypedEnvelope {
type_byte: u8,
},
WrongFieldCount {
expected: usize,
found: usize,
},
FieldDecode {
field: LegacyTransactionField,
source: DecodeError,
},
InvalidToLength {
found: usize,
},
}Expand description
Legacy transaction decode failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Envelope(TransactionEnvelopeError)
Envelope classification failed before legacy fields could be decoded.
TypedEnvelope
A typed envelope was supplied to the legacy decoder.
WrongFieldCount
Legacy transaction list did not contain exactly nine fields.
FieldDecode
A field failed RLP or primitive-domain decoding.
Fields

field: LegacyTransactionFieldField being decoded.

source: DecodeErrorUnderlying decode error.
InvalidToLength
The to field was neither empty nor a 20-byte address.
Implementations