#[non_exhaustive]pub enum ProtocolError {
Feature(FeatureError),
Fork(ForkError),
InvalidStateTransition,
}Expand description
Protocol validation failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Feature(FeatureError)
A feature is disabled or unsupported for the selected operation.
Fork(ForkError)
Fork context is missing, unsupported, or inactive.
InvalidStateTransition
A validation state transition was attempted out of order.
Implementations