#[non_exhaustive]pub enum TransactionEncodeErrorCategory {
MalformedInput,
ResourceExhaustion,
}Expand description
Stable high-level transaction encode error categories.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MalformedInput
A field, length, or output buffer is malformed for canonical encoding.
ResourceExhaustion
A bounded codec policy rejected an encoded list payload.