#[non_exhaustive]pub enum TransactionEnvelopeErrorCategory {
MalformedInput,
Unsupported,
ResourceExhaustion,
}Expand description
Stable high-level transaction envelope error categories.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MalformedInput
Input is malformed for an EIP-2718 or legacy transaction envelope.
Unsupported
A typed transaction prefix is intentionally unsupported by this shell.
ResourceExhaustion
The active decode policy rejected the input as too large or too deep.