CanonicalValidationProof

Struct CanonicalValidationProof 

pub struct CanonicalValidationProof { /* private fields */ }
Proof that canonical transaction structure was checked.

This proof is intentionally not publicly constructible yet. Public constructors must bind the proof to the transaction identity they attest to before validators can create this value.