SenderRecoveryProof

Struct SenderRecoveryProof 

pub struct SenderRecoveryProof { /* private fields */ }
Proof that sender recovery succeeded.

This proof is intentionally not publicly constructible yet. Public constructors must bind the proof to the transaction identity they attest to before validators can create this value.