pub struct SetCodeAuthorizationAuthority {
pub authorization_index: usize,
pub authority: Address,
}Expand description
Authority recovered for one authorization tuple.
Callers should create this value only from a successful
eth-valkyoth-verify authorization signature validation result.
Fields
Index of the authorization tuple in the transaction authorization list.
Recovered authorizing account.