pub struct StateTransitionError<State> { /* private fields */ }Expand description
Failed state transition that returns the original transaction token.
Implementations
Sourceimpl<State> StateTransitionError<State>
impl<State> StateTransitionError<State>
Sourcepub const fn error(&self) -> ProtocolError
pub const fn error(&self) -> ProtocolError
Returns the validation error that prevented promotion.
Sourcepub fn into_parts(self) -> (Transaction<State>, ProtocolError)
pub fn into_parts(self) -> (Transaction<State>, ProtocolError)
Splits this error into the original transaction token and error.