Crate eth_valkyoth_protocol

Crate eth_valkyoth_protocol 

Fork-aware Ethereum protocol validation state.

Structs

AccessList
Borrowed EIP-2930 access list.
AccessListEntries
Iterator over borrowed access-list entries.
AccessListEntry
Borrowed EIP-2930 access-list entry.
AccessListStorageKeyItems
Iterator over borrowed storage keys.
AccessListStorageKeys
Borrowed storage-key list for one access-list address.
BlobVersionedHashItems
Iterator over borrowed blob versioned hashes.
BlobVersionedHashes
Borrowed EIP-4844 blob versioned hash list.
Canonical
Canonical wire form and type-specific structure were checked.
CanonicalValidationProof
Proof that canonical transaction structure was checked.
ChainSpec
Explicit chain rules used to select fork validation context.
Decoded
Raw wire input was accepted by the codec.
ForkSpec
Ethereum fork rules selected for a validation operation.
ForkValidated
Fork-specific validity was checked.
ForkValidationProof
Proof that fork-specific transaction validity was checked.
InvalidSignatureYParity
Invalid EIP-2930/EIP-1559 signature y-parity bit.
SenderRecovered
Sender recovery succeeded.
SenderRecoveryProof
Proof that sender recovery succeeded.
SetCodeAuthorization
Borrowed EIP-7702 authorization tuple.
SetCodeAuthorizationChainId
EIP-7702 authorization chain ID.
SetCodeAuthorizationItems
Iterator over borrowed EIP-7702 authorization tuples.
SetCodeAuthorizationList
Borrowed EIP-7702 authorization list.
StateTransitionError
Failed state transition that returns the original transaction token.
Transaction
A transaction token whose validation state is tracked at compile time.
TypedTransactionEnvelope
Borrowed EIP-2718 typed transaction shell.
UnvalidatedAccessListTransaction
Borrowed EIP-2930 transaction decoded only into field domains.
UnvalidatedBlobTransaction
Borrowed EIP-4844 transaction decoded only into field domains.
UnvalidatedDynamicFeeTransaction
Borrowed EIP-1559 transaction decoded only into field domains.
UnvalidatedLegacyTransaction
Borrowed legacy transaction decoded only into field domains.
UnvalidatedSetCodeTransaction
Borrowed EIP-7702 set-code transaction decoded only into field domains.
ValidationContext
Validation context that must be explicit for consensus-sensitive operations.

Enums

AccessListTransactionDecodeError
EIP-2930 access-list transaction decode failure.
AccessListTransactionDecodeErrorCategory
Stable high-level access-list transaction decode error categories.
AccessListTransactionField
EIP-2930 transaction field identifier.
AccessListTransactionTo
EIP-2930 transaction call/create target.
BlobTransactionDecodeError
EIP-4844 blob transaction decode failure.
BlobTransactionDecodeErrorCategory
Stable high-level blob transaction decode error categories.
BlobTransactionField
EIP-4844 transaction field identifier.
DynamicFeeTransactionDecodeError
EIP-1559 dynamic-fee transaction decode failure.
DynamicFeeTransactionDecodeErrorCategory
Stable high-level dynamic-fee transaction decode error categories.
DynamicFeeTransactionField
EIP-1559 transaction field identifier.
FeatureError
Feature availability failure.
ForkActivation
Unambiguous fork activation rule.
ForkError
Fork selection or activation failure.
Hardfork
Execution-layer hardfork identity used by explicit chain specs.
LegacyTransactionDecodeError
Legacy transaction decode failure.
LegacyTransactionDecodeErrorCategory
Stable high-level legacy transaction decode error categories.
LegacyTransactionField
Legacy transaction field identifier.
LegacyTransactionTo
Legacy transaction call/create target.
ProtocolError
Protocol validation failure.
ProtocolErrorCategory
Stable high-level protocol error categories.
SetCodeAuthorizationField
EIP-7702 authorization tuple sub-field identifier.
SetCodeTransactionDecodeError
EIP-7702 set-code transaction decode failure.
SetCodeTransactionDecodeErrorCategory
Stable high-level set-code transaction decode error categories.
SetCodeTransactionField
EIP-7702 transaction field identifier.
SignatureYParity
EIP-2930 signature y parity.
TransactionEncodeError
Transaction envelope encoding failure.
TransactionEncodeErrorCategory
Stable high-level transaction encode error categories.
TransactionEnvelope
Borrowed transaction envelope shell.
TransactionEnvelopeError
Transaction envelope classification failure.
TransactionEnvelopeErrorCategory
Stable high-level transaction envelope error categories.
UnvalidatedTransaction
Supported unvalidated transaction domains accepted by the encoder.

Constants

ACCESS_LIST_TRANSACTION_FIELD_COUNT
Number of fields in an EIP-2930 access-list transaction payload.
ACCESS_LIST_TRANSACTION_TYPE
EIP-2930 transaction type byte.
BLOB_TRANSACTION_FIELD_COUNT
Number of fields in an EIP-4844 blob transaction payload.
BLOB_TRANSACTION_TYPE
EIP-4844 blob transaction type byte.
DYNAMIC_FEE_TRANSACTION_FIELD_COUNT
Number of fields in an EIP-1559 dynamic-fee transaction payload.
DYNAMIC_FEE_TRANSACTION_TYPE
EIP-1559 dynamic-fee transaction type byte.
EIP_2718_MAX_TYPED_PREFIX
Largest single-byte EIP-2718 typed transaction prefix.
EIP_2718_RESERVED_PREFIX
Prefix reserved by EIP-2718 as a future extension sentinel.
EIP_2718_SCALAR_PREFIX_START
First RLP scalar prefix that cannot be a typed transaction envelope or a legacy transaction list.
EIP_2718_TYPED_ZERO_PREFIX
EIP-2718 byte value reserved by this crate for the legacy transaction domain.
LEGACY_TRANSACTION_FIELD_COUNT
Number of fields in a canonical legacy transaction RLP list.
LEGACY_TRANSACTION_PREFIX_START
First byte used by canonical RLP short-list legacy transactions.
SET_CODE_AUTHORIZATION_FIELD_COUNT
Number of fields in an EIP-7702 authorization tuple.
SET_CODE_TRANSACTION_FIELD_COUNT
Number of fields in an EIP-7702 set-code transaction payload.
SET_CODE_TRANSACTION_TYPE
EIP-7702 set-code transaction type byte.

Functions

decode_access_list_transaction
Decodes an EIP-2930 access-list transaction into unvalidated field domains.
decode_blob_transaction
Decodes an EIP-4844 blob transaction into unvalidated field domains.
decode_dynamic_fee_transaction
Decodes an EIP-1559 dynamic-fee transaction into unvalidated field domains.
decode_legacy_transaction
Decodes a canonical legacy transaction into unvalidated field domains.
decode_set_code_transaction
Decodes an EIP-7702 set-code transaction into unvalidated field domains.
decode_transaction_envelope
Classifies a borrowed transaction envelope under explicit decode limits.
encode_access_list_signing_preimage
Encodes the EIP-2930 signing preimage.
encode_access_list_transaction
Canonically encodes an EIP-2930 access-list transaction.
encode_blob_signing_preimage
Encodes the EIP-4844 signing preimage.
encode_blob_transaction
Canonically encodes an EIP-4844 blob transaction.
encode_dynamic_fee_signing_preimage
Encodes the EIP-1559 signing preimage.
encode_dynamic_fee_transaction
Canonically encodes an EIP-1559 dynamic-fee transaction.
encode_legacy_eip155_signing_preimage
Encodes the EIP-155 legacy signing preimage.
encode_legacy_transaction
Canonically encodes a legacy transaction.
encode_set_code_transaction
Canonically encodes an EIP-7702 set-code transaction.
encode_transaction
Canonically encodes an admitted unvalidated transaction envelope.
encoded_access_list_signing_preimage_len
Returns the EIP-2930 signing preimage length.
encoded_access_list_transaction_len
Returns the canonical encoded EIP-2930 transaction length.
encoded_blob_signing_preimage_len
Returns the EIP-4844 signing preimage length.
encoded_blob_transaction_len
Returns the canonical encoded EIP-4844 transaction length.
encoded_dynamic_fee_signing_preimage_len
Returns the EIP-1559 signing preimage length.
encoded_dynamic_fee_transaction_len
Returns the canonical encoded EIP-1559 transaction length.
encoded_legacy_eip155_signing_preimage_len
Returns the EIP-155 legacy signing preimage length.
encoded_legacy_transaction_len
Returns the canonical encoded legacy transaction length.
encoded_set_code_transaction_len
Returns the canonical encoded EIP-7702 transaction length.
encoded_transaction_len
Returns the canonical encoded transaction envelope length.

Type Aliases

DynamicFeeTransactionTo
EIP-1559 transaction call/create target.