Crate eth_valkyoth_protocol

Crate eth_valkyoth_protocol 

Fork-aware Ethereum protocol validation state.

Structs

Canonical
Canonical wire form and type-specific structure were checked.
Decoded
Raw wire input was accepted by the codec.
ForkSpec
Ethereum fork rules selected for a validation operation.
ForkValidated
Fork-specific validity was checked.
SenderRecovered
Sender recovery succeeded.
Transaction
A transaction token whose validation state is tracked at compile time.
TypedTransactionEnvelope
Borrowed EIP-2718 typed transaction shell.
UnvalidatedLegacyTransaction
Borrowed legacy transaction decoded only into field domains.
ValidationContext
Validation context that must be explicit for consensus-sensitive operations.

Enums

FeatureError
Feature availability failure.
ForkActivation
Unambiguous fork activation rule.
ForkError
Fork selection or activation failure.
LegacyTransactionDecodeError
Legacy transaction decode failure.
LegacyTransactionDecodeErrorCategory
Stable high-level legacy transaction decode error categories.
LegacyTransactionField
Legacy transaction field identifier.
LegacyTransactionTo
Legacy transaction call/create target.
ProtocolError
Protocol validation failure.
ProtocolErrorCategory
Stable high-level protocol error categories.
TransactionEnvelope
Borrowed transaction envelope shell.
TransactionEnvelopeError
Transaction envelope classification failure.
TransactionEnvelopeErrorCategory
Stable high-level transaction envelope error categories.

Constants

EIP_2718_MAX_TYPED_PREFIX
Largest single-byte EIP-2718 typed transaction prefix.
EIP_2718_RESERVED_PREFIX
Prefix reserved by EIP-2718 as a future extension sentinel.
EIP_2718_SCALAR_PREFIX_START
First RLP scalar prefix that cannot be a typed transaction envelope or a legacy transaction list.
EIP_2718_TYPED_ZERO_PREFIX
EIP-2718 byte value reserved by this crate for the legacy transaction domain.
LEGACY_TRANSACTION_FIELD_COUNT
Number of fields in a canonical legacy transaction RLP list.
LEGACY_TRANSACTION_PREFIX_START
First byte used by canonical RLP short-list legacy transactions.

Functions

decode_legacy_transaction
Decodes a canonical legacy transaction into unvalidated field domains.
decode_transaction_envelope
Classifies a borrowed transaction envelope under explicit decode limits.