#[non_exhaustive]pub enum ForkError {
Unsupported,
Inactive,
MissingActivation,
}Expand description
Fork selection or activation failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unsupported
The selected fork is not supported by this crate version.
Inactive
The selected fork is not active for the supplied validation context.
MissingActivation
Fork activation data is incomplete.
Implementations